@@ -6,7 +6,6 @@
 //!  - `'data` is the lifetime of data that is owned by the Janet GC.
 use core::{
     cmp::Ordering,
-    convert::TryFrom,
     fmt::{self, Display, Write},
 };
 
@@ -18,8 +17,6 @@ use alloc::{
 #[cfg(feature = "std")]
 use std::error;
 
-use const_fn::const_fn;
-
 use evil_janet::{Janet as CJanet, JanetType as CJanetType};
 
 pub mod array;
@@ -1221,7 +1218,6 @@ impl From<Janet> for TaggedJanet<'_> {
 
 impl TaggedJanet<'_> {
     #[inline]
-    #[const_fn("1.46")]
     pub const fn kind(&self) -> JanetType {
         match self {
             TaggedJanet::Abstract(_) => JanetType::Abstract,
@@ -1704,7 +1700,7 @@ string_impl_partial_ord!(#[cfg(feature = "std")]; JanetKeyword<'_>, &'a bstr::BS
 
 
 /// Trait that only exist to extend methods over `[Janet]` so it's easier to get
-/// #[janet_fn] args.
+/// [`janet_fn`](crate::janet_fn) args.
 pub trait JanetArgs {
     /// Get the argument at the `index` position and tries to convert to `T`.
     fn get_unwraped<T: TryFrom<Janet>>(&self, index: usize) -> Result<T, T::Error>;
