@@ -100,7 +100,7 @@ impl<'data> JanetStruct<'data> {
     // Get the [`JanetStructHead`] from the `JanetStruct` pointer.
     #[inline]
     fn head(&self) -> &JanetStructHead {
-        // Safety: Janet struct are always be a valid pointer
+        // SAFETY: Janet struct are always be a valid pointer
         unsafe { &*evil_janet::janet_struct_head(self.raw) }
     }
 
@@ -220,7 +220,7 @@ impl<'data> JanetStruct<'data> {
     /// Returns a reference to the value corresponding to the `key` without checking for
     /// anything.
     ///
-    /// # SAFETY
+    /// # Safety
     /// This function doesn't check for null pointer and if the key or value as Janet nil
     #[inline]
     pub(crate) unsafe fn get_unchecked(&self, key: impl Into<Janet>) -> &'data Janet {
@@ -230,7 +230,7 @@ impl<'data> JanetStruct<'data> {
     /// Returns the key-value pair corresponding to the supplied `key`, with a reference
     /// to value without checking for anything.
     ///
-    /// # SAFETY
+    /// # Safety
     /// This function doesn't check for null pointer and if the key or value as Janet nil
     #[inline]
     pub(crate) unsafe fn get_key_value_unchecked(
@@ -263,7 +263,7 @@ impl<'data> JanetStruct<'data> {
     ///     .finalize();
     /// assert_eq!(st.get_owned(10), Some(Janet::from("ten")));
     /// ```
-    #[inline]
+    #[cfg_attr(feature = "inline-more", inline)]
     pub fn get_owned(&self, key: impl Into<Janet>) -> Option<Janet> {
         let key = key.into();
 
@@ -285,7 +285,7 @@ impl<'data> JanetStruct<'data> {
     ///
     /// let st = JanetStruct::builder(2).put(10, "ten").put(11, "eleven").finalize();
     /// assert_eq!(st.get_owned_key_value(10), Some((Janet::integer(10), Janet::from("ten"))));
-    #[inline]
+    #[cfg_attr(feature = "inline-more", inline)]
     pub fn get_owned_key_value(&self, key: impl Into<Janet>) -> Option<(Janet, Janet)> {
         let key = key.into();
         self.get_owned(key).map(|v| (key, v))
@@ -341,7 +341,7 @@ impl<'data> JanetStruct<'data> {
     /// assert!(st.contains_key(10));
     /// assert!(!st.contains_key(11));
     /// ```
-    #[inline]
+    #[cfg_attr(feature = "inline-more", inline)]
     pub fn contains_key(&self, key: impl Into<Janet>) -> bool {
         self.get(key).is_some()
     }
@@ -358,7 +358,7 @@ impl<'data> JanetStruct<'data> {
     /// assert!(st.contains("ten"));
     /// assert!(!st.contains(11));
     /// ```
-    #[inline]
+    #[cfg_attr(feature = "inline-more", inline)]
     pub fn contains(&self, value: impl Into<Janet>) -> bool {
         let value = value.into();
         self.values().any(|&v| v == value)
@@ -491,19 +491,16 @@ impl Eq for JanetStruct<'_> {}
 impl PartialOrd for JanetStruct<'_> {
     #[inline]
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
-        use core::cmp::Ordering::*;
+        use core::cmp::Ordering::{Equal, Greater, Less};
 
         match self.len().cmp(&other.len()) {
-            x @ Less => Some(x),
-            x @ Greater => Some(x),
+            x @ (Less | Greater) => Some(x),
             Equal => match self.head().hash.cmp(&other.head().hash) {
-                x @ Less => Some(x),
-                x @ Greater => Some(x),
+                x @ (Less | Greater) => Some(x),
                 Equal => {
                     for (s, ref o) in self.iter().zip(other.iter()) {
                         match s.partial_cmp(o) {
-                            x @ Some(Less) => return x,
-                            x @ Some(Greater) => return x,
+                            x @ Some(Less | Greater) => return x,
                             Some(Equal) => continue,
                             None => return None,
                         }
@@ -518,19 +515,16 @@ impl PartialOrd for JanetStruct<'_> {
 impl Ord for JanetStruct<'_> {
     #[inline]
     fn cmp(&self, other: &Self) -> Ordering {
-        use core::cmp::Ordering::*;
+        use core::cmp::Ordering::{Equal, Greater, Less};
 
         match self.len().cmp(&other.len()) {
-            x @ Less => x,
-            x @ Greater => x,
+            x @ (Less | Greater) => x,
             Equal => match self.head().hash.cmp(&other.head().hash) {
-                x @ Less => x,
-                x @ Greater => x,
+                x @ (Less | Greater) => x,
                 Equal => {
                     for (s, ref o) in self.iter().zip(other.iter()) {
                         match s.cmp(o) {
-                            x @ Less => return x,
-                            x @ Greater => return x,
+                            x @ (Less | Greater) => return x,
                             Equal => continue,
                         }
                     }
@@ -585,7 +579,7 @@ impl From<&JanetTable<'_>> for JanetStruct<'_> {
     fn from(table: &JanetTable<'_>) -> Self {
         let mut st = Self::builder(table.len());
 
-        for (k, v) in table.into_iter() {
+        for (k, v) in table {
             st = st.put(k, v);
         }
 
